"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Ignore = exports.Simulate = undefined;
exports.mount = mount;
exports.unmount = unmount;
exports.simulate = simulate;

var _testUtils = require("react-dom/test-utils");

Object.defineProperty(exports, "Simulate", {
  enumerable: true,
  get: function get() {
    return _testUtils.Simulate;
  }
});

var _Ignore = require("./Ignore");

Object.defineProperty(exports, "Ignore", {
  enumerable: true,
  get: function get() {
    return _interopRequireDefault(_Ignore).default;
  }
});

var _reactDom = require("react-dom");

var _reactDom2 = _interopRequireDefault(_reactDom);

var _domspace = require("domspace");

var _domspace2 = _interopRequireDefault(_domspace);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function mount(element) {
  var container = document.createElement("div");
  _reactDom2.default.render(element, container);
  return container.firstChild;
}

function unmount(element) {
  _reactDom2.default.unmountComponentAtNode(element.parentNode);
}

function simulate(rootElement, events) {
  [].concat(events).map(function (event) {
    return typeof event === "string" ? { type: event } : event;
  }).forEach(function (event) {
    var target = rootElement;

    if (event.target) {
      target = rootElement.querySelector(event.target);
      if (!target) {
        throw new Error("Could not trigger " + event.type + " on '" + event.target + "' in\n" + (0, _domspace2.default)(rootElement.cloneNode(true)).outerHTML);
      }
    }

    if (event.type === "change" && typeof event.value === "string") {
      target.value = event.value;
    }

    if (!_testUtils.Simulate[event.type]) {
      throw new Error("Event '" + event.type + "' is not supported by Simulate\nSee https://reactjs.org/docs/events.html#supported-events");
    }

    _testUtils.Simulate[event.type](target, event.data);
  });
}